/****************************************************************************
** Meta object code from reading C++ file 'mainwindow.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kontact-26.04.2/src/mainwindow.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mainwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7Kontact10MainWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto Kontact::MainWindow::qt_create_metaobjectdata<qt_meta_tag_ZN7Kontact10MainWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kontact::MainWindow",
        "D-Bus Interface",
        "org.kde.kontact.KontactInterface",
        "selectPlugin",
        "",
        "KontactInterface::Plugin*",
        "plugin",
        "pluginName",
        "slotActionTriggered",
        "QAction*",
        "action",
        "identifier",
        "updateConfig",
        "initObject",
        "initGUI",
        "slotActivePartChanged",
        "KParts::Part*",
        "part",
        "slotPreferences",
        "slotNewClicked",
        "slotQuit",
        "slotNewToolbarConfig",
        "slotShowIntroduction",
        "slotShowStatusMsg",
        "activateInitialPluginModule",
        "slotOpenUrl",
        "QUrl",
        "url",
        "pluginsChanged",
        "configureShortcuts",
        "configureToolbars",
        "slotShowHideSideBar",
        "slotSplitterMoved",
        "pos",
        "index"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'selectPlugin'
        QtMocHelpers::SlotData<void(KontactInterface::Plugin *)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'selectPlugin'
        QtMocHelpers::SlotData<void(const QString &)>(3, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'slotActionTriggered'
        QtMocHelpers::SlotData<void(QAction *, const QString &)>(8, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { QMetaType::QString, 11 },
        }}),
        // Slot 'updateConfig'
        QtMocHelpers::SlotData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'initObject'
        QtMocHelpers::SlotData<void()>(13, 4, QMC::AccessProtected, QMetaType::Void),
        // Slot 'initGUI'
        QtMocHelpers::SlotData<void()>(14, 4, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotActivePartChanged'
        QtMocHelpers::SlotData<void(KParts::Part *)>(15, 4, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Slot 'slotPreferences'
        QtMocHelpers::SlotData<void()>(18, 4, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotNewClicked'
        QtMocHelpers::SlotData<void()>(19, 4, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotQuit'
        QtMocHelpers::SlotData<void()>(20, 4, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotNewToolbarConfig'
        QtMocHelpers::SlotData<void()>(21, 4, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotShowIntroduction'
        QtMocHelpers::SlotData<void()>(22, 4, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotShowStatusMsg'
        QtMocHelpers::SlotData<void(const QString &)>(23, 4, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Slot 'activateInitialPluginModule'
        QtMocHelpers::SlotData<void()>(24, 4, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotOpenUrl'
        QtMocHelpers::SlotData<void(const QUrl &)>(25, 4, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 26, 27 },
        }}),
        // Slot 'pluginsChanged'
        QtMocHelpers::SlotData<void()>(28, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'configureShortcuts'
        QtMocHelpers::SlotData<void()>(29, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'configureToolbars'
        QtMocHelpers::SlotData<void()>(30, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotShowHideSideBar'
        QtMocHelpers::SlotData<void()>(31, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSplitterMoved'
        QtMocHelpers::SlotData<void(int, int)>(32, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 33 }, { QMetaType::Int, 34 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<MainWindow, qt_meta_tag_ZN7Kontact10MainWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Kontact::MainWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<KontactInterface::Core::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Kontact10MainWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Kontact10MainWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Kontact10MainWindowE_t>.metaTypes,
    nullptr
} };

void Kontact::MainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MainWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->selectPlugin((*reinterpret_cast<std::add_pointer_t<KontactInterface::Plugin*>>(_a[1]))); break;
        case 1: _t->selectPlugin((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->slotActionTriggered((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 3: _t->updateConfig(); break;
        case 4: _t->initObject(); break;
        case 5: _t->initGUI(); break;
        case 6: _t->slotActivePartChanged((*reinterpret_cast<std::add_pointer_t<KParts::Part*>>(_a[1]))); break;
        case 7: _t->slotPreferences(); break;
        case 8: _t->slotNewClicked(); break;
        case 9: _t->slotQuit(); break;
        case 10: _t->slotNewToolbarConfig(); break;
        case 11: _t->slotShowIntroduction(); break;
        case 12: _t->slotShowStatusMsg((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->activateInitialPluginModule(); break;
        case 14: _t->slotOpenUrl((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 15: _t->pluginsChanged(); break;
        case 16: _t->configureShortcuts(); break;
        case 17: _t->configureToolbars(); break;
        case 18: _t->slotShowHideSideBar(); break;
        case 19: _t->slotSplitterMoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KontactInterface::Plugin* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KParts::Part* >(); break;
            }
            break;
        }
    }
}

const QMetaObject *Kontact::MainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kontact::MainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Kontact10MainWindowE_t>.strings))
        return static_cast<void*>(this);
    return KontactInterface::Core::qt_metacast(_clname);
}

int Kontact::MainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KontactInterface::Core::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    return _id;
}
QT_WARNING_POP
